@@ -72,7 +72,8 @@ cluster.bs.ivreg<-function(mod, dat, cluster, ci.level = 0.95, boot.reps = 1000,
   dat <- dat[used.idx,]                                             # keep only active observations (drop the missing)
   clust <- as.vector(unlist(dat[[clust.name]]))                     # store cluster index in convenient vector
   G<-length(unique(clust))                                          # how many clusters are in this model?
-  ind.variables <- names(coefficients(mod))                         # what independent variables are in this model?
+  ind.variables <- rownames(summary(mod)$coefficients)              # what independent variables are in this model?
+  ind.variables.full <- names(coefficients(mod))                    # what independent variables (incld drops) are in this model?
   
   
   # load in a function to create clustered standard errors
@@ -233,6 +234,12 @@ cluster.bs.ivreg<-function(mod, dat, cluster, ci.level = 0.95, boot.reps = 1000,
     cat("\n", "Confidence Intervals (derived from bootstrapped t-statistics): ", "\n", "\n")
     printmat(print.ci)
     
+    if(length(ind.variables) < length(ind.variables.full)){
+      cat("\n", "\n", "****", "Note: ", length(ind.variables.full) - length(ind.variables), " variables were unidentified in the model and are not reported.", "****", "\n", sep="")
+      cat("Variables not reported:", "\n", sep="")
+      cat(ind.variables.full[!ind.variables.full %in% ind.variables], sep=", ")
+      cat("\n", "\n")
+    }
     
   }
   
